bayespref-package:
Hierarchical Bayesian analysis of ecological count data
Description
This program implements a hierarchical Bayesian analysis of count data, such as preference experiments. It provides population-level and individual-level preference parameter estimates obtained via MCMC. It also allows for model comparison using Deviance Information Criterion.
Arguments
Details
Package:
bayespref
Type:
Package
Version:
1.0
Date:
2011-05-16
License:
GPL (>= 2)
LazyLoad:
yes
For information regarding functions implemented in bayespref, please see the appropriate function help pages.